# Retinol
Python package for converting wavelength spectra of e.g. petals to trichromatic insect vision. Designed to be used as a colab notebook, to ease the process.

How do insects see the world? A recent review shows the magnitude of variation of visual perception across the phylum of insects (van der Kooi et al. 2021). Nonetheless, many of which have a set of 3 different wavelength receptors, covering a range of wavelengths from ~300 to ~700 nm (or in words, from UV to red). As there is no direct physical way of measuring this perception, a framework combining physiological exminations, wavelength measurements and mathematical transformations was set up during the 20th century (Wyszecki & Spines 1982, Chittka & Waser 1997). Thus, it is possible to compare different flowers by how they are perceived by an insect. This notebook implements the concept described by Chittka & Kevan (2005) (and basically shares its nomenclature) and enables the comparison of multiple species of flowers on how they are sensed by a trichromatic insect eye.

For any questions or help please contact thomas.huber<at>evobio.eu

